# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['shoestring',
 'shoestring.commands',
 'shoestring.healthagents',
 'shoestring.internal',
 'shoestring.wizard',
 'shoestring.wizard.screens']

package_data = \
{'': ['*']}

install_requires = \
['Jinja2==3.1.2',
 'PyYAML==6.0.1',
 'aiohttp==3.8.5',
 'prompt-toolkit==3.0.39',
 'requests==2.31.0',
 'symbol-lightapi==0.0.4',
 'symbol-sdk-python==3.0.11',
 'websockets==11.0.3',
 'zenlog==1.1']

setup_kwargs = {
    'name': 'symbol-shoestring',
    'version': '0.0.3',
    'description': 'Symbol Shoestring Deployment Tool',
    'long_description': '# shoestring\n\n# CLI Commands\n\n## Setup Commands\n\n### init\n\nExtracts a template shoestring configuration file from a package that the user can then customize.\n\n```\ninit [--package PACKAGE] config\n\n  config             path to shoestring configuration file\n  --package PACKAGE  Network configuration package. Possible values: (name | file:///filename | http(s)://uri) (default: mainnet)\n```\n\n### min-cosignatures-count\n\nAutomatically detects the minimum cosignatures required for an account and optionally updates the shoestring configuration file.\n\n```\nmin-cosignatures-count --config CONFIG --ca-key-path CA_KEY_PATH [--update]\n\n  --config CONFIG           path to shoestring configuration file\n  --ca-key-path CA_KEY_PATH path to main private key PEM file\n  --update                  update the shoestring configuration file\n```\n\n### import-bootstrap\n\nImports settings from a symbol-bootstap installation.\n\n\n```\nimport-bootstrap --config CONFIG --bootstrap BOOTSTRAP\n\n  --config CONFIG       path to shoestring configuration file\n  --bootstrap BOOTSTRAP path to bootstrap target directory\n```\n\n### pemtool\n\nGenerates a main private key PEM file that can be used by shoestring.\n\n```\npemtool --output OUTPUT [--input INPUT] [--ask-pass] [--force]\n\n  --output OUTPUT  output PEM key file\n  --input INPUT    input private key file (optional)\n  --ask-pass       encrypt PEM with a password (password prompt will be shown)\n  --force          overwrite output file if it already exists\n```\n\n### setup\n\nSets up a Symbol node from scratch\n\n```\nsetup \\\n    --config CONFIG \\\n    [--package PACKAGE] \\\n    [--directory DIRECTORY] \\\n    [--overrides OVERRIDES] \\\n    [--metadata METADATA] \\\n    [--security {default,paranoid,insecure}] \\\n    --ca-key-path CA_KEY_PATH\n\n  --config CONFIG           path to shoestring configuration file\n  --package PACKAGE         Network configuration package. Possible values: (name | file:///filename | http(s)://uri) (default: mainnet)\n  --directory DIRECTORY     installation directory (default: $HOME)\n  --overrides OVERRIDES     path to custom user settings\n  --metadata METADATA       custom node metadata (this is only valid for API roles)\n  --security                security mode (default: default)\n  --ca-key-path CA_KEY_PATH path to main private key PEM file\n```\n\nPlease note that only security mode "default" is supported at this time.\n\nThis command will generate a transaction that will need to be sent to the network using `announce-transaction` to update the network state.\n\n## Operational Commands\n\n### signer\n\nSigns a transaction that can then be announced to the network\n\n```\nsigner --config CONFIG --ca-key-path CA_KEY_PATH [--save] filename\n\n  filename                  transaction binary payload\n  --config CONFIG           path to shoestring configuration file\n  --ca-key-path CA_KEY_PATH path to main private key PEM file\n  --save                    save signed payload into same file as input\n```\n\n### announce-transaction\n\nAnnounces a transaction to the network.\n\n```\nannounce-transaction --config CONFIG --transaction TRANSACTION\n\n  --config CONFIG           path to shoestring configuration file\n  --transaction TRANSACTION file containing serialized transaction to send\n```\n\n### health\n\nChecks the health of the local Symbol node.\n\n\n```\nhealth [-h] --config CONFIG [--directory DIRECTORY]\n\n  --config CONFIG       path to shoestring configuration file\n  --directory DIRECTORY installation directory (default: $HOME)\n```\n\n## Upgrade Commands\n\n### upgrade\n\nUpgrades a node to the latest client version.\n\n```\nupgrade \\\n    --config CONFIG \\\n    [--package PACKAGE] \\\n    [--directory DIRECTORY] \\\n    [--overrides OVERRIDES] \\\n    [--metadata METADATA]\n\n  --config CONFIG           path to shoestring configuration file\n  --package PACKAGE         Network configuration package. Possible values: (name | file:///filename | http(s)://uri) (default: mainnet)\n  --directory DIRECTORY     installation directory (default: $HOME)\n  --overrides OVERRIDES     path to custom user settings\n  --metadata METADATA       custom node metadata (this is only valid for API roles)\n```\n\n### renew-certificates\n\nRenews peer certificates.\n\n```\nrenew-certificates --config CONFIG [--directory DIRECTORY] --ca-key-path CA_KEY_PATH [--renew-ca]\n\n  --config CONFIG           path to shoestring configuration file\n  --directory DIRECTORY     installation directory (default: $HOME)\n  --ca-key-path CA_KEY_PATH path to main private key PEM file\n  --renew-ca                renews CA certificate too\n```\n\nWhen `--renew-ca` is set, both CA and node certificates will be regenerated. Otherwise, only node certificate will be.\n\n### renew-voting-keys\n\nRenews voting keys.\n\n```\nrenew-voting-keys --config CONFIG [--directory DIRECTORY]\n\n  --config CONFIG           path to shoestring configuration file\n  --directory DIRECTORY     installation directory (default: $HOME)\n```\n\nThis command will generate a transaction that will need to be sent to the network using `announce-transaction` to update the network state.\n\n### reset-data\n\nResets blockchain state to allow a resync from scratch.\n\n```\nreset-data --config CONFIG [--directory DIRECTORY] [--purge-harvesters]\n\n  --config CONFIG           path to shoestring configuration file\n  --directory DIRECTORY     installation directory (default: $HOME)\n  --purge-harvesters        purge harvesters.dat file\n```\n\nWhen `--purge-harvesters` is set, delegates discovered using old keys will be discarded.\n\n\n## Files\n\n### Shoestring Configuration INI\n\nINI file used by shoestring to customize a Symbol node deployment.\nIt is composed of five sections: `network`, `images`, `services`, `transaction`, `imports`, `node`.\n\n#### network\n\nDescribes properties of network that deployed node should connect with.\nThese should match values in `config-network.properties` Symbol configuration file.\nIf `init` command is used, these values shouldn\'t be modified\n\n```\nname                  Network name\nidentifier            Network numeric identifier\nepochAdjustment       Network epoch adjustment\ngenerationHashSeed    Network generation hash seed\n```\n\n#### images\n\nDescribes Symbol docker images to use.\nIf `init` command is used, these values shouldn\'t be modified\n```\nclient  Catapult client docker image\nrest    REST docker image\n```\n\n#### services\n\nDescribes network services to use during deployment.\nIf `init` command is used, these values shouldn\'t be modified\n\n```\nnodewatch  URL to nodewatch service.\n```\n\n#### transactions\n\nDescribes properties of generated transactions.\nIf `init` command is used, most of these values _generally_ shouldn\'t be modified.\n`min-cosignatures-count` command can be used to automatically update `minCosignaturesCount` setting.\n\nGeneral properties:\n```\nfeeMultiplier             Min fee multiplier of generated transactions\ntimeoutHours              Timeout of generated transactions (in hours)\nminCosignaturesCount      Minimum number of cosignatures generated transactions will require\n```\n\nWhen `signer` command is signing an aggregate bonded transaction, it will additionally generate a hash lock transaction\nusing the following properties:\n```\nhashLockDuration          Hash lock duration in blocks\ncurrencyMosaicId          Network currency mosaid id\nlockedFundsPerAggregate   Locked funds per aggregate\n```\n\n#### imports\n\nDescribes keys to import.\nThese need to be manually set if there are harvesting and/or voting keys that need to be imported.\n\n```\nharvester Path to a config-harvesting.properties Symbol configuration file containing harvesting keys to import\nvoter     Path to a directory containing private_key_tree*.day files to import\n```\n\n#### node\n\nDescribes settings to customize a node.\n\n`features` supports the following:\n* `PEER` - Peer support\n* `API` - REST support\n* `HARVESTER` - Node will be configured to harvest and accept delegated harvesters\n* `VOTER` - Node will be configured to vote\n\n`caPassword` supports all available openssl passphrase options: https://www.openssl.org/docs/man3.0/man1/openssl-passphrase-options.html.\n\n```\nfeatures       One or more node features to deploy (| delimited)\nuserId         User id of node used to set process and file permissons\ngroupId        Group id of node used to set process and file permissons\ncaPassword     Password of CA (main) PEM private key file (if applicable)\napiHttps       Set to enable HTTPS REST (only applicable when features include API)\n\ncaCommonName   Common name of generated CA certificates\nnodeCommonName Common name of generated Node certificates\n```\n\n### Overrides\n\nINI file that is used to customize advanced Symbol settings.\n\nSections should have the format `[<config-short-name>.<config-section>]`.\nSection contents will then be applied to the appropriate Symbol configuration file.\n\nFor example, in order to set two custom settings:\n1. `connectTimeout` - located in the `config-node.properties` file in section `node`\n1. `maxUnlockedAccounts` - located in the `config-harvesting.properties` file in section `harvesting`\n\nThe following snippet will suffice:\n\n```ini\n[node.node]\n\nconnectTimeout = 5s\n\n[harvesting.harvesting]\n\nmaxUnlockedAccounts = 2\n```\n\nNotice that these custom settings are applied *BEFORE* shoestring updates the Symbol configuration files.\nIn cases of conflicts, the shoestring changes will take precedence.\n\n### Node Metadata\n\nJSON file that is ingested and used to replace the contents of `nodeMetadata` in rest.json.\nThis data is then accessible via the `node/metadata` REST endpoint.\nThis file is optional and only used for deployments including API role.\n\n## Prerequisites:\n\n    apt-get install python3 python3-pip openssl\n    python3 -m pip install -r requirements.txt\n\n## Temporarily (until lightapi package fix):\n\n```\ncd product/lightapi/python\n./scripts/ci/setup_lint.sh\n./scripts/ci/lint.sh\n./scripts/ci/test.sh\n\n# to run shoestring\n\nPYTHONPATH=}full path here{/product/lightapi/python python3 -m shoestring\n```\n',
    'author': 'Symbol Contributors',
    'author_email': 'contributors@symbol.dev',
    'maintainer': 'Symbol Contributors',
    'maintainer_email': 'contributors@symbol.dev',
    'url': 'https://github.com/symbol/product/tree/main/tools/shoestring',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
